==> libgtop-2.9.90.tar.bz2: libgtop-2.9.90/sysdeps/linux/mem.c <==
/* $Id: mem.c,v 1.28 2004/11/28 01:32:55 bdejean Exp $ */

/* Copyright (C) 1998-99 Martin Baulig
   This file is part of LibGTop 1.0.

   Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.

   LibGTop is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License,
   or (at your option) any later version.

   LibGTop is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
   for more details.

   You should have received a copy of the GNU General Public License
   along with LibGTop; see the file COPYING. If not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include <config.h>
#include <glibtop/error.h>
#include <glibtop/mem.h>

#include "glibtop_private.h"

static const unsigned long _glibtop_sysdeps_mem =
(1L << GLIBTOP_MEM_TOTAL) + (1L << GLIBTOP_MEM_USED) +
(1L << GLIBTOP_MEM_FREE) + (1L << GLIBTOP_MEM_SHARED) +
(1L << GLIBTOP_MEM_BUFFER) + (1L << GLIBTOP_MEM_CACHED) +
(1L << GLIBTOP_MEM_USER);

/* Init function. */

void
glibtop_init_mem_s (glibtop *server)
{
	server->sysdeps.mem = _glibtop_sysdeps_mem;
}

/* Provides information about memory usage. */

#define FILENAME	"/proc/meminfo"

void
glibtop_get_mem_s (glibtop *server, glibtop_mem *buf)
{
	char buffer [BUFSIZ];

	glibtop_init_s (&server, GLIBTOP_SYSDEPS_MEM, 0);

	memset(buf, 0, sizeof *buf);

	file_to_buffer(server, buffer, FILENAME);

	buf->total  = get_scaled(buffer, "MemTotal:");
	buf->free   = get_scaled(buffer, "MemFree:");
	buf->used   = buf->total - buf->free;
	buf->shared = 0;
	buf->buffer = get_scaled(buffer, "Buffers:");
	buf->cached = get_scaled(buffer, "Cached:");

	buf->user = buf->total - buf->free - buf->cached - buf->buffer;
	buf->flags = _glibtop_sysdeps_mem;
}

==> libgtop-2.14.9.tar.bz2: libgtop-2.14.9/sysdeps/linux/mem.c <==
/* Copyright (C) 1998-99 Martin Baulig
   This file is part of LibGTop 1.0.

   Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.

   LibGTop is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License,
   or (at your option) any later version.

   LibGTop is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
   for more details.

   You should have received a copy of the GNU General Public License
   along with LibGTop; see the file COPYING. If not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include <config.h>
#include <glibtop/error.h>
#include <glibtop/mem.h>

#include "glibtop_private.h"

static const unsigned long _glibtop_sysdeps_mem =
(1L << GLIBTOP_MEM_TOTAL) + (1L << GLIBTOP_MEM_USED) +
(1L << GLIBTOP_MEM_FREE) + (1L << GLIBTOP_MEM_SHARED) +
(1L << GLIBTOP_MEM_BUFFER) + (1L << GLIBTOP_MEM_CACHED) +
(1L << GLIBTOP_MEM_USER);

/* Init function. */

void
_glibtop_init_mem_s (glibtop *server)
{
	server->sysdeps.mem = _glibtop_sysdeps_mem;
}

/* Provides information about memory usage. */

#define FILENAME	"/proc/meminfo"

void
glibtop_get_mem_s (glibtop *server, glibtop_mem *buf)
{
	char buffer [BUFSIZ];

	glibtop_init_s (&server, GLIBTOP_SYSDEPS_MEM, 0);

	memset(buf, 0, sizeof *buf);

	file_to_buffer(server, buffer, FILENAME);

	buf->total  = get_scaled(buffer, "MemTotal:");
	buf->free   = get_scaled(buffer, "MemFree:");
	buf->used   = buf->total - buf->free;
	buf->shared = 0;
	buf->buffer = get_scaled(buffer, "Buffers:");
	buf->cached = get_scaled(buffer, "Cached:");

	buf->user = buf->total - buf->free - buf->cached - buf->buffer;
	buf->flags = _glibtop_sysdeps_mem;
}
